DriveKitDriverDataAndroid class
The Android implementation of DriveKitDriverDataPlatform.
- Inheritance
-
- Object
- PlatformInterface
- DriveKitDriverDataPlatform
- DriveKitDriverDataAndroid
Constructors
- DriveKitDriverDataAndroid({AndroidDriverDataApi? androidDriverDataApi})
-
Creates a new instance of DriveKitDriverDataAndroid.
The optional
androidDriverDataApiparameter is used for dependency injection in tests.
Properties
- androidDriverDataApi → AndroidDriverDataApi
-
The instance of
AndroidDriverDataApi, a class that provides access to the native methods via a method channel generated by pigeon.final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteTrip(
String itinId) → Future< bool> -
Delete a trip
override
-
getRoute(
String itinId) → Future< GetRouteResponse?> -
Get route by trip identifier
override
-
getTrip(
String itinId) → Future< GetTripResponse?> -
Get trip by identider
override
-
getTripsOrderByDateAsc(
{SynchronizationType synchronizationType = SynchronizationType.defaultSync, List< TransportationMode> transportationModes = const <TransportationMode>[]}) → Future<GetTripsResponse?> -
Get trips ordered by date Ascending
override
-
getTripsOrderByDateDesc(
{SynchronizationType synchronizationType = SynchronizationType.defaultSync, List< TransportationMode> transportationModes = const <TransportationMode>[]}) → Future<GetTripsResponse?> -
Get trips ordered by date Descending
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateDriverPassengerMode(
String itinId, DriverPassengerMode mode, String comment) → Future< UpdateDriverPassengerModeStatus> -
Declare a trip made as passenger or driver
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
) → void -
Registers this class as the default instance of
DriveKitDriverDataPlatform